// Copyright (c) 2013 by István Váradi

// This file is part of XPLRA, a remote-access plugin for X-Plane

// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:

// 1. Redistributions of source code must retain the above copyright notice, this
//    list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright notice,
//    this list of conditions and the following disclaimer in the documentation
//    and/or other materials provided with the distribution.

// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
// ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
// (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
// LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
// ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// The views and conclusions contained in the software and documentation are those
// of the authors and should not be interpreted as representing official policies,
// either expressed or implied, of the FreeBSD Project.

//------------------------------------------------------------------------------

#include <hu/varadiistvan/xplra/XPlane.h>

#include <hu/varadiistvan/scpl/Thread.h>

#include <cstdio>
#include <cstring>

//------------------------------------------------------------------------------

using hu::varadiistvan::xplra::XPlane;
using hu::varadiistvan::xplra::Exception;
using hu::varadiistvan::xplra::ProtocolException;

using hu::varadiistvan::scpl::Thread;

using std::string;

//------------------------------------------------------------------------------

int main()
{
    try {
        XPlane xplane;

        printf("Connecting to X-Plane...\n");
        xplane.connect();
        printf("Connected to X-Plane.\n\n");

        printf("Registering hotkeys: Ctrl+A, Shift+B, Ctrl+Shift+C, Ctrl+Q...\n");
        uint16_t codes[] = { 0x0241, 0x0142, 0x0343, 0x0251 };
        xplane.registerHotkeys(codes, sizeof(codes)/sizeof(uint16_t));
        printf("Registered hotkeys...\n\n");

        printf("Listening to hotkeys...\n");
        while(true) {
            uint8_t states[4];
            xplane.queryHotkeys(states, sizeof(states));
            if (states[3]!=0) {
                xplane.unregisterHotkeys();
                break;
            }

            char message[256];
            message[0] = '\0';

            if (states[0]!=0) {
                if (message[0]!='\0') strcat(message, ", ");
                strcat(message, "Ctrl+A");
            }
            if (states[1]!=0) {
                if (message[0]!='\0') strcat(message, ", ");
                strcat(message, "Shift+B");
            }
            if (states[2]!=0) {
                if (message[0]!='\0') strcat(message, ", ");
                strcat(message, "Ctrl+Shift+C");
            }

            if (message[0]!='\0') {
                strcat(message, " pressed");
                xplane.showMessage(message, 3.0);
            }

            Thread::sleep(500);
        }


    } catch(const Exception& exception) {
        printf("\n>>>>>>>>>>>>>>>>> Exception caugth: %s\n", exception.what());

        return 1;
    }
}

//------------------------------------------------------------------------------

// Local Variables:
// mode: C++
// c-basic-offset: 4
// indent-tabs-mode: nil
// End:
